==> thirdparty-service-biz-1.0.29-20210721.064956-4-sources.jar: cn/com/duiba/domain/AppDO.java <==
package cn.com.duiba.domain;

/**
 * APPDO
 */
public class AppDO {

	/**
	 * app id
	 */
	private Long id;
	/**
	 * 开发者id
	 */
	private Long developerId;
	/**
	 * 积分消耗的结果通知地址
	 */
	private String creditsConsumeNotifyUrl;
	/**
	 * 兑换记录通知链接
	 */
	private String recordNotifyUrl;
	/**
	 * appKey
	 */
	private String appKey;
	/**
	 * secretCode
	 */
	private String secretCode;
	/**
	 * 开关
	 */
	private Long appSwitch;

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public String getCreditsConsumeNotifyUrl() {
		return creditsConsumeNotifyUrl;
	}

	public void setCreditsConsumeNotifyUrl(String creditsConsumeNotifyUrl) {
		this.creditsConsumeNotifyUrl = creditsConsumeNotifyUrl;
	}

	public String getAppKey() {
		return appKey;
	}

	public void setAppKey(String appKey) {
		this.appKey = appKey;
	}

	public String getSecretCode() {
		return secretCode;
	}

	public void setSecretCode(String secretCode) {
		this.secretCode = secretCode;
	}

	public String getRecordNotifyUrl() {
		return recordNotifyUrl;
	}

	public void setRecordNotifyUrl(String recordNotifyUrl) {
		this.recordNotifyUrl = recordNotifyUrl;
	}

	public Long getDeveloperId() {
		return developerId;
	}

	public void setDeveloperId(Long developerId) {
		this.developerId = developerId;
	}

	public Long getAppSwitch() {
		return appSwitch;
	}

	public void setAppSwitch(Long appSwitch) {
		this.appSwitch = appSwitch;
	}

	@Override
	public String toString() {
		return "AppDO{" +
				"id=" + id +
				", developerId=" + developerId +
				", creditsConsumeNotifyUrl='" + creditsConsumeNotifyUrl + '\'' +
				", recordNotifyUrl='" + recordNotifyUrl + '\'' +
				", appKey='" + appKey + '\'' +
				", secretCode='" + secretCode + '\'' +
				", appSwitch=" + appSwitch +
				'}';
	}
}

==> thirdparty-service-biz-1.0.33.1-20210906.061255-2-sources.jar: cn/com/duiba/domain/AppDO.java <==
package cn.com.duiba.domain;

/**
 * APPDO
 */
public class AppDO {

	/**
	 * app id
	 */
	private Long id;
	/**
	 * 开发者id
	 */
	private Long developerId;
	/**
	 * 积分消耗的结果通知地址
	 */
	private String creditsConsumeNotifyUrl;
	/**
	 * 兑换记录通知链接
	 */
	private String recordNotifyUrl;
	/**
	 * appKey
	 */
	private String appKey;
	/**
	 * secretCode
	 */
	private String secretCode;
	/**
	 * 开关
	 */
	private Long appSwitch;
	//业务主体 1:兑吧，2:兑啊，3:兑捷
	private Integer subject;

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public String getCreditsConsumeNotifyUrl() {
		return creditsConsumeNotifyUrl;
	}

	public void setCreditsConsumeNotifyUrl(String creditsConsumeNotifyUrl) {
		this.creditsConsumeNotifyUrl = creditsConsumeNotifyUrl;
	}

	public String getAppKey() {
		return appKey;
	}

	public void setAppKey(String appKey) {
		this.appKey = appKey;
	}

	public String getSecretCode() {
		return secretCode;
	}

	public void setSecretCode(String secretCode) {
		this.secretCode = secretCode;
	}

	public String getRecordNotifyUrl() {
		return recordNotifyUrl;
	}

	public void setRecordNotifyUrl(String recordNotifyUrl) {
		this.recordNotifyUrl = recordNotifyUrl;
	}

	public Long getDeveloperId() {
		return developerId;
	}

	public void setDeveloperId(Long developerId) {
		this.developerId = developerId;
	}

	public Long getAppSwitch() {
		return appSwitch;
	}

	public void setAppSwitch(Long appSwitch) {
		this.appSwitch = appSwitch;
	}

	public Integer getSubject() {
		return subject;
	}

	public void setSubject(Integer subject) {
		this.subject = subject;
	}

	@Override
	public String toString() {
		return "AppDO{" +
				"id=" + id +
				", developerId=" + developerId +
				", creditsConsumeNotifyUrl='" + creditsConsumeNotifyUrl + '\'' +
				", recordNotifyUrl='" + recordNotifyUrl + '\'' +
				", appKey='" + appKey + '\'' +
				", secretCode='" + secretCode + '\'' +
				", appSwitch=" + appSwitch +
				'}';
	}
}
